#
# spec file for package brightnessctl
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019 R Tyler Croy <rtyler@brokenco.de>
# Copyright (c) 2016 Fabio Alessandro Locati <fale@fedoraproject.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# use systemd-logind instead of udev for systemd >= 243
%if 0%{?sle_version} >= 150200 || 0%{?suse_version} > 1500
%global use_logind 1
%else
%global use_logind 0
%endif
Name:           brightnessctl
Version:        0.5.1
Release:        1.12
Summary:        Tool to read and control device brightness
License:        MIT
URL:            https://github.com/Hummer12007/%{name}
Source:         %{URL}/archive/%{version}.tar.gz
PreReq:         permissions
BuildRequires:  gcc
BuildRequires:  make
%if %{use_logind}
BuildRequires:  pkgconfig(libsystemd)
Requires:       systemd >= 243
%else
BuildRequires:  systemd-rpm-macros
%endif

%description
A utility to read and control the display brightness.

%prep
%autosetup -N

%build
%if %{use_logind}
export ENABLE_SYSTEMD=1
%{set_build_flags}
%else
export MODE="4755"
export CFLAGS="%{optflags}"
%endif
%make_build

%install
%if %{use_logind}
%make_install INSTALL_UDEV_RULES=0 ENABLE_SYSTEMD=1 PREFIX=%{_prefix}
%else
%make_install UDEVDIR=%{_udevrulesdir}
%endif

%post
%if 0%{?set_permissions:1}
    %set_permissions %name
%else
    %run_permissions
%endif

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%if ! %{use_logind}
%{_udevrulesdir}/90-brightnessctl.rules
%endif
%{_mandir}/man1/brightnessctl.1%{?ext_man}

%changelog
* Sun Feb  2 2020 R. Tyler Croy <rtyler@brokenco.de>
-  Upgrade to the recently released 0.5.1, which includes previously applied
  patches
  Removed patches (adding this for the bot):
  0001-Fixed-inconsistency-in-README-thanks-AJGQ.patch
  0002-Support-the-new-SetBrightness-logind-API.patch
  0003-Make-the-use-of-SetBrightness-dynamic.patch
  0004-Use-non-suid-permissions-when-logind-is-used.patch
* Thu Jan 30 2020 Dan Čermák <dcermak@suse.com>
- Add support for using logind mode for recent distributions
  cherry pick patches from upstream:
  * 0001-Fixed-inconsistency-in-README-thanks-AJGQ.patch
  * 0002-Support-the-new-SetBrightness-logind-API.patch
  * 0003-Make-the-use-of-SetBrightness-dynamic.patch
  * 0004-Use-non-suid-permissions-when-logind-is-used.patch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed May  1 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
- Remove redundant DESTDIR= from %%make_install.
- Require systemd-rpm-macros for %%_udevrulesdir.
* Tue Apr 30 2019 mvetter@suse.com
- Clean spec
- Add SUSE copyright
* Sat Feb 23 2019 R. Tyler Croy <rtyler@brokenco.de>
- Package 0.4 for openSUSE
* Sun Sep 24 2017 Fabio Alessandro Locati <fale@fedoraproject.org>
- Upgrade to 0.3
* Wed Aug  2 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild
* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild
* Thu Jan 19 2017 Fabio Alessandro Locati <fale@fedoraproject.org>
- Update to 0.2.1
* Wed Jan 18 2017 Fabio Alessandro Locati <fale@fedoraproject.org>
- Update to 0.2
* Sun Nov 27 2016 Fabio Alessandro Locati <fale@fedoraproject.org>
- Improvements thanks to Igor review
* Sun Nov 27 2016 Fabio Alessandro Locati <fale@fedoraproject.org>
- Initial packaging
